@@ -1,38 +1,22 @@
-# -*- coding: utf-8 -*-
+# SPDX-License-Identifier: GPL-2.0-or-later
 #
 # Copyright (C) 2011-2016 Red Hat, Inc.
 #
 # Authors:
 # Thomas Woerner <twoerner@redhat.com>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
 
-__all__ = [ "FirewallIcmpType" ]
-
-import copy
 from firewall.core.logger import log
 from firewall import errors
 from firewall.errors import FirewallError
 
-class FirewallIcmpType(object):
+
+class FirewallIcmpType:
     def __init__(self, fw):
         self._fw = fw
-        self._icmptypes = { }
+        self._icmptypes = {}
 
     def __repr__(self):
-        return '%s(%r)' % (self.__class__, self._icmptypes)
+        return "%s(%r)" % (self.__class__, self._icmptypes)
 
     def cleanup(self):
         self._icmptypes.clear()
@@ -53,8 +37,7 @@ class FirewallIcmpType(object):
     def add_icmptype(self, obj):
         orig_ipvs = obj.destination
         if len(orig_ipvs) == 0:
-            orig_ipvs = [ "ipv4", "ipv6" ]
-        ipvs = orig_ipvs[:]
+            orig_ipvs = ["ipv4", "ipv6"]
         for ipv in orig_ipvs:
             if ipv == "ipv4":
                 if not self._fw.ip4tables_enabled and not self._fw.nftables_enabled:
@@ -65,19 +48,13 @@ class FirewallIcmpType(object):
                     continue
                 supported_icmps = self._fw.ipv6_supported_icmp_types
             else:
-                supported_icmps = [ ]
+                supported_icmps = []
             if obj.name.lower() not in supported_icmps:
-                log.info1("ICMP type '%s' is not supported by the kernel for %s." % (obj.name, ipv))
-                ipvs.remove(ipv)
-        if len(ipvs) != len(orig_ipvs):
-            if len(ipvs) < 1:
-                raise FirewallError(errors.INVALID_ICMPTYPE,
-                                    "No supported ICMP type.")
-            new_obj = copy.deepcopy(obj)
-            new_obj.destination = ipvs
-            self._icmptypes[obj.name] = new_obj
-        else:
-            self._icmptypes[obj.name] = obj
+                log.info1(
+                    "ICMP type '%s' is not supported by the kernel for %s."
+                    % (obj.name, ipv)
+                )
+        self._icmptypes[obj.name] = obj
 
     def remove_icmptype(self, icmptype):
         self.check_icmptype(icmptype)
